UnitsTime

Enum UnitsTime 

pub enum UnitsTime {
Show 24 variants Ys, Zs, Es, Ps, Ts, Gs, Ms, ks, hs, das, s, ds, cs, ms, us, ns, ps, fs, as, zs, ys, min, h, d,
}

Variants



Ys



Zs



Es



Ps



Ts



Gs



Ms



ks



hs



das



s



ds



cs



ms



us



ns



ps



fs



as



zs



ys



min



h



d

Implementations

Source

impl UnitsTime

pub fn variants() -> Vec<Self>

all possible variants of this enum that can be constructed or converted into